@@ -495,7 +495,7 @@ class HTTPSClientCertTransport(HttpTransport):
                     OpenSSL.SSL.FILETYPE_PEM, file(key).read(), str(password))
             else:
                 bio = M2Crypto.BIO.openfile(key)
-                rsa = M2Crypto.m2.rsa_read_key(bio._ptr(), lambda *unused: None)
+                rsa = M2Crypto.m2.rsa_read_key(bio._ptr(), lambda *unused: "")
                 if not rsa:
                     raise OpenSSL.crypto.Error
                 client_keyobj = OpenSSL.crypto.load_privatekey(
